# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`dhcp`](#dhcp): Manage an ISC DHCP server
* [`dhcp::disable`](#dhcpdisable): Remove and Disable the DHCP server
* [`dhcp::failover`](#dhcpfailover): Define a failover peer

#### Private Classes

* `dhcp::params`: Default parameters

### Defined types

* [`dhcp::dhcp_class`](#dhcpdhcp_class): Define a DHCP class
* [`dhcp::host`](#dhcphost): Define a DHCP host reservation
* [`dhcp::pool`](#dhcppool): Define a DHCP pool

### Data types

* [`Dhcp::Macaddress`](#dhcpmacaddress)
* [`Dhcp::Range`](#dhcprange)
* [`Dhcp::StaticRoute`](#dhcpstaticroute)

## Classes

### <a name="dhcp"></a>`dhcp`

Manage an ISC DHCP server

#### Parameters

The following parameters are available in the `dhcp` class:

* [`dnsdomain`](#dnsdomain)
* [`nameservers`](#nameservers)
* [`failover`](#failover)
* [`bootp`](#bootp)
* [`ntpservers`](#ntpservers)
* [`interfaces`](#interfaces)
* [`interface`](#interface)
* [`default_lease_time`](#default_lease_time)
* [`max_lease_time`](#max_lease_time)
* [`dnskeyname`](#dnskeyname)
* [`dnsupdatekey`](#dnsupdatekey)
* [`dnsupdateserver`](#dnsupdateserver)
* [`omapi`](#omapi)
* [`omapi_name`](#omapi_name)
* [`omapi_algorithm`](#omapi_algorithm)
* [`omapi_key`](#omapi_key)
* [`pxeserver`](#pxeserver)
* [`pxefilename`](#pxefilename)
* [`ipxe_filename`](#ipxe_filename)
* [`mtu`](#mtu)
* [`bootfiles`](#bootfiles)
* [`logfacility`](#logfacility)
* [`dhcp_monitor`](#dhcp_monitor)
* [`dhcp_dir`](#dhcp_dir)
* [`manage_dhcp_dir`](#manage_dhcp_dir)
* [`conf_dir_mode`](#conf_dir_mode)
* [`packagename`](#packagename)
* [`servicename`](#servicename)
* [`option_static_route`](#option_static_route)
* [`options`](#options)
* [`authoritative`](#authoritative)
* [`dhcp_root_user`](#dhcp_root_user)
* [`dhcp_root_group`](#dhcp_root_group)
* [`ddns_updates`](#ddns_updates)
* [`ddns_domainname`](#ddns_domainname)
* [`ddns_rev_domainname`](#ddns_rev_domainname)
* [`ddns_update_style`](#ddns_update_style)
* [`client_updates`](#client_updates)
* [`pools`](#pools)
* [`hosts`](#hosts)
* [`includes`](#includes)
* [`config_comment`](#config_comment)

##### <a name="dnsdomain"></a>`dnsdomain`

Data type: `Array[String]`



Default value: `$dhcp::params::dnsdomain`

##### <a name="nameservers"></a>`nameservers`

Data type: `Array[String]`



Default value: `[]`

##### <a name="failover"></a>`failover`

Data type: `Boolean`



Default value: ``false``

##### <a name="bootp"></a>`bootp`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ntpservers"></a>`ntpservers`

Data type: `Array[String]`



Default value: `[]`

##### <a name="interfaces"></a>`interfaces`

Data type: `Optional[Array[String]]`



Default value: ``undef``

##### <a name="interface"></a>`interface`

Data type: `String`



Default value: `'NOTSET'`

##### <a name="default_lease_time"></a>`default_lease_time`

Data type: `Integer[0]`



Default value: `43200`

##### <a name="max_lease_time"></a>`max_lease_time`

Data type: `Integer[0]`



Default value: `86400`

##### <a name="dnskeyname"></a>`dnskeyname`

Data type: `String`



Default value: `'rndc-key'`

##### <a name="dnsupdatekey"></a>`dnsupdatekey`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="dnsupdateserver"></a>`dnsupdateserver`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="omapi"></a>`omapi`

Data type: `Boolean`



Default value: ``true``

##### <a name="omapi_name"></a>`omapi_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="omapi_algorithm"></a>`omapi_algorithm`

Data type: `String`



Default value: `'HMAC-MD5'`

##### <a name="omapi_key"></a>`omapi_key`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="pxeserver"></a>`pxeserver`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="pxefilename"></a>`pxefilename`

Data type: `String`



Default value: `$dhcp::params::pxefilename`

##### <a name="ipxe_filename"></a>`ipxe_filename`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="mtu"></a>`mtu`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="bootfiles"></a>`bootfiles`

Data type: `Hash[String, String]`



Default value: `$dhcp::params::bootfiles`

##### <a name="logfacility"></a>`logfacility`

Data type: `String`



Default value: `'local7'`

##### <a name="dhcp_monitor"></a>`dhcp_monitor`

Data type: `Boolean`



Default value: ``true``

##### <a name="dhcp_dir"></a>`dhcp_dir`

Data type: `Stdlib::Absolutepath`



Default value: `$dhcp::params::dhcp_dir`

##### <a name="manage_dhcp_dir"></a>`manage_dhcp_dir`

Data type: `Boolean`



Default value: `$dhcp::params::manage_dhcp_dir`

##### <a name="conf_dir_mode"></a>`conf_dir_mode`

Data type: `Optional[Stdlib::Filemode]`



Default value: `$dhcp::params::conf_dir_mode`

##### <a name="packagename"></a>`packagename`

Data type: `String`



Default value: `$dhcp::params::packagename`

##### <a name="servicename"></a>`servicename`

Data type: `String`



Default value: `$dhcp::params::servicename`

##### <a name="option_static_route"></a>`option_static_route`

Data type: `Any`



Default value: ``undef``

##### <a name="options"></a>`options`

Data type: `Variant[Array[String], Optional[String]]`



Default value: ``undef``

##### <a name="authoritative"></a>`authoritative`

Data type: `Boolean`



Default value: ``false``

##### <a name="dhcp_root_user"></a>`dhcp_root_user`

Data type: `String`



Default value: `'root'`

##### <a name="dhcp_root_group"></a>`dhcp_root_group`

Data type: `String`



Default value: `$dhcp::params::root_group`

##### <a name="ddns_updates"></a>`ddns_updates`

Data type: `Boolean`



Default value: ``false``

##### <a name="ddns_domainname"></a>`ddns_domainname`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ddns_rev_domainname"></a>`ddns_rev_domainname`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ddns_update_style"></a>`ddns_update_style`

Data type: `Enum['none', 'interim', 'standard']`



Default value: `'interim'`

##### <a name="client_updates"></a>`client_updates`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="pools"></a>`pools`

Data type: `Hash[String, Hash]`



Default value: `{}`

##### <a name="hosts"></a>`hosts`

Data type: `Hash[String, Hash]`



Default value: `{}`

##### <a name="includes"></a>`includes`

Data type: `Variant[Array[String], Optional[String]]`



Default value: ``undef``

##### <a name="config_comment"></a>`config_comment`

Data type: `String`



Default value: `'dhcpd.conf'`

### <a name="dhcpdisable"></a>`dhcp::disable`

Remove and Disable the DHCP server

### <a name="dhcpfailover"></a>`dhcp::failover`

Define a failover peer

#### Parameters

The following parameters are available in the `dhcp::failover` class:

* [`peer_address`](#peer_address)
* [`role`](#role)
* [`address`](#address)
* [`port`](#port)
* [`max_response_delay`](#max_response_delay)
* [`max_unacked_updated`](#max_unacked_updated)
* [`mclt`](#mclt)
* [`load_split`](#load_split)
* [`load_balance`](#load_balance)
* [`omapi_key`](#omapi_key)
* [`max_unacked_updates`](#max_unacked_updates)

##### <a name="peer_address"></a>`peer_address`

Data type: `String`

The address of the failover peer.

##### <a name="role"></a>`role`

Data type: `Enum['primary', 'secondary']`

Primary or Secondary role in DHCP failover relationship.

Default value: `'primary'`

##### <a name="address"></a>`address`

Data type: `String`

IP Address of the DHCP failover server.

Default value: `$facts['networking']['ip']`

##### <a name="port"></a>`port`

Data type: `Variant[Integer[0, 65535], String]`

Port to listen for failover messages.

Default value: `519`

##### <a name="max_response_delay"></a>`max_response_delay`

Data type: `Variant[Integer[0], String]`

max-response-delay in seconds before failover peer is considered failed.

Default value: `30`

##### <a name="max_unacked_updated"></a>`max_unacked_updated`

max-unacked-updates before the server will wait to send additional packets to peer.

##### <a name="mclt"></a>`mclt`

Data type: `Variant[Integer[0], String]`

MCLT, the maximum time a lease may be extended beyond expiration set by DHCP peer.

Default value: `300`

##### <a name="load_split"></a>`load_split`

Data type: `Variant[Integer[0], String]`

Load split between the DHCP servers as fraction out of 256.

Default value: `128`

##### <a name="load_balance"></a>`load_balance`

Data type: `Variant[Integer[0], String]`

Load balance max seconds, cutoff after which load balancing is disabled.

Default value: `3`

##### <a name="omapi_key"></a>`omapi_key`

Data type: `Optional[String]`

OMAPI key to cryptographically sign traffic if OMAPI protocol is enabled.

Default value: ``undef``

##### <a name="max_unacked_updates"></a>`max_unacked_updates`

Data type: `Variant[Integer[0], String]`



Default value: `10`

## Defined types

### <a name="dhcpdhcp_class"></a>`dhcp::dhcp_class`

Define a DHCP class

#### Parameters

The following parameters are available in the `dhcp::dhcp_class` defined type:

* [`parameters`](#parameters)

##### <a name="parameters"></a>`parameters`

Data type: `Variant[Array[String], String]`

The parameters for the class definition. When specified as a string, it
will be used verbatim with a semi colon at the end. When specified as an
array, every string is used and appended with a semi colon.

### <a name="dhcphost"></a>`dhcp::host`

Define a DHCP host reservation

#### Parameters

The following parameters are available in the `dhcp::host` defined type:

* [`ip`](#ip)
* [`mac`](#mac)
* [`comment`](#comment)

##### <a name="ip"></a>`ip`

Data type: `String`

The IP address in the reservation

##### <a name="mac"></a>`mac`

Data type: `Dhcp::Macaddress`

The host's MAC address

##### <a name="comment"></a>`comment`

Data type: `Optional[String]`

An optional comment for the host

Default value: ``undef``

### <a name="dhcppool"></a>`dhcp::pool`

Define a DHCP pool

#### Parameters

The following parameters are available in the `dhcp::pool` defined type:

* [`network`](#network)
* [`mask`](#mask)
* [`gateway`](#gateway)
* [`pool_parameters`](#pool_parameters)
* [`range`](#range)
* [`failover`](#failover)
* [`options`](#options)
* [`parameters`](#parameters)
* [`mtu`](#mtu)
* [`nameservers`](#nameservers)
* [`pxeserver`](#pxeserver)
* [`pxefilename`](#pxefilename)
* [`domain_name`](#domain_name)
* [`static_routes`](#static_routes)
* [`search_domains`](#search_domains)
* [`raw_append`](#raw_append)
* [`raw_prepend`](#raw_prepend)

##### <a name="network"></a>`network`

Data type: `String`



##### <a name="mask"></a>`mask`

Data type: `String`



##### <a name="gateway"></a>`gateway`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="pool_parameters"></a>`pool_parameters`

Data type: `Variant[Array[String], Optional[String]]`



Default value: ``undef``

##### <a name="range"></a>`range`

Data type: `Variant[Array[Dhcp::Range], Optional[Dhcp::Range], Enum[''], Boolean]`



Default value: ``undef``

##### <a name="failover"></a>`failover`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="options"></a>`options`

Data type: `Variant[Array[String], Optional[String]]`



Default value: ``undef``

##### <a name="parameters"></a>`parameters`

Data type: `Variant[Array[String], Optional[String]]`



Default value: ``undef``

##### <a name="mtu"></a>`mtu`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="nameservers"></a>`nameservers`

Data type: `Variant[Array[String], Optional[String]]`



Default value: ``undef``

##### <a name="pxeserver"></a>`pxeserver`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="pxefilename"></a>`pxefilename`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="domain_name"></a>`domain_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="static_routes"></a>`static_routes`

Data type: `Optional[Array[Dhcp::StaticRoute]]`



Default value: ``undef``

##### <a name="search_domains"></a>`search_domains`

Data type: `Variant[Array[String], Optional[String]]`



Default value: ``undef``

##### <a name="raw_append"></a>`raw_append`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="raw_prepend"></a>`raw_prepend`

Data type: `Optional[String]`



Default value: ``undef``

## Data types

### <a name="dhcpmacaddress"></a>`Dhcp::Macaddress`

The Dhcp::Macaddress data type.

Alias of

```puppet
Pattern[/^[0-9A-Fa-f]{1,2}(:[0-9A-Fa-f]{1,2}){5}$/]
```

### <a name="dhcprange"></a>`Dhcp::Range`

The Dhcp::Range data type.

Alias of

```puppet
Pattern[/^(dynamic-bootp )?((([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))[.]){3}([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d)))(\/((([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))[.]){3}([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))|[0-9]+))?( ((([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))[.]){3}([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d)))(\/((([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))[.]){3}([0-9](?!\d)|[1-9][0-9](?!\d)|1[0-9]{2}(?!\d)|2[0-4][0-9](?!\d)|25[0-5](?!\d))|[0-9]+))?)?$/]
```

### <a name="dhcpstaticroute"></a>`Dhcp::StaticRoute`

The Dhcp::StaticRoute data type.

Alias of

```puppet
Struct[{
    'mask'              => String,
    'gateway'           => String,
    Optional['network'] => String,
  }]
```

